@@ -28,12 +28,9 @@
 
 struct CM_CREATEQUEUE_PARAM
 {
-    unsigned int cmQueueType;   // [in]
-    bool cmRunAloneMode;        // [in]
-    unsigned int cmGPUContext;  // [in]
-    unsigned int cmSSEUUsageHint; // [in]
-    void *cmQueueHandle;        // [out]
-    int32_t returnValue;        // [out]
+    CM_QUEUE_CREATE_OPTION createOption; // [in/out]
+    void *cmQueueHandle;                 // [out]
+    int32_t returnValue;                 // [out]
 };
 
 struct CM_ENQUEUE_PARAM
@@ -89,18 +86,34 @@ struct CM_ENQUEUE_GPUCOPY_L2L_PARAM
     void *cmQueueHandle;  // [in]
     void *srcSysMem;      // [in]
     void *dstSysMem;      // [in]
-    uint32_t copySize;     // [in]
+    uint32_t copySize;    // [in]
     uint32_t option;      // [in]
     void *cmEventHandle;  // [out]
     uint32_t eventIndex;  // [out] index of Event in m_EventArray
     int32_t returnValue;  // [out]
 };
 
+
+struct CM_ENQUEUE_COPY_BUFFER_PARAM
+{
+    void* cmQueueHandle;  // [in]
+    void* buffer;         // [in]
+    void* sysMem;         // [in]
+    uint32_t offset;      // [in]
+    uint64_t copySize;    // [in]
+    uint32_t copyDir;     // [in]
+    void* wait_event;     // [in]
+    void* cmEventHandle;  // [out]
+    uint32_t option;      // [in]
+    uint32_t eventIndex;  // [out] index of Event in m_EventArray
+    int32_t  returnValue; // [out]
+};
+
 struct CM_ENQUEUE_2DInit_PARAM
 {
     void *cmQueueHandle;  // [in]
     void *cmSurface2d;    // [in]
-    uint32_t initValue;  // [in]
+    uint32_t initValue;   // [in]
     void *cmEventHandle;  // [out]
     uint32_t eventIndex;  // [out] index of Event in m_EventArray
     int32_t returnValue;  // [out]
@@ -115,26 +128,6 @@ struct CM_ENQUEUE_VEBOX_PARAM
     int32_t returnValue;  // [out] return value
 };
 
-int32_t CmQueue_RT::Create(CmDevice_RT *device, CmQueue_RT *&queue)
-{
-    int32_t result = CM_SUCCESS;
-    queue = new(std::nothrow) CmQueue_RT(device, CM_DEFAULT_QUEUE_CREATE_OPTION);
-    if (queue)
-    {
-        result = queue->Initialize();
-        if (result != CM_SUCCESS)
-        {
-            CmQueue_RT::Destroy(queue);
-        }
-    }
-    else
-    {
-        CmAssert(0);
-        result = CM_OUT_OF_HOST_MEMORY;
-    }
-    return result;
-}
-
 int32_t CmQueue_RT::Create(CmDevice_RT *device, CmQueue_RT *&queue, CM_QUEUE_CREATE_OPTION queueCreateOption)
 {
     int32_t result = CM_SUCCESS;
@@ -178,10 +171,7 @@ int32_t CmQueue_RT::Initialize()
     CHK_FAILURE_RETURN(hr);
     CHK_FAILURE_RETURN(inParam.returnValue);
     m_cmQueueHandle = inParam.cmQueueHandle;
-    m_queueOption.QueueType = (CM_QUEUE_TYPE)inParam.cmQueueType;
-    m_queueOption.RunAloneMode = inParam.cmRunAloneMode;
-    m_queueOption.GPUContext = inParam.cmGPUContext;
-    m_queueOption.SseuUsageHint = (CM_QUEUE_SSEU_USAGE_HINT_TYPE)inParam.cmSSEUUsageHint;
+    m_queueOption   = inParam.createOption;
     return CM_SUCCESS;
 }
 
@@ -189,10 +179,7 @@ int32_t CmQueue_RT::Initialize(CM_QUEUE_CREATE_OPTION queueCreateOption)
 {
     CM_CREATEQUEUE_PARAM inParam;
     CmSafeMemSet(&inParam, 0, sizeof(inParam));
-    inParam.cmQueueType = queueCreateOption.QueueType;
-    inParam.cmRunAloneMode = queueCreateOption.RunAloneMode;
-    inParam.cmGPUContext = queueCreateOption.GPUContext;
-    inParam.cmSSEUUsageHint = queueCreateOption.SseuUsageHint;
+    inParam.createOption = queueCreateOption;
 
     int32_t hr = m_cmDev->OSALExtensionExecute(CM_FN_CMDEVICE_CREATEQUEUEEX,
                                                 &inParam, sizeof(inParam));
@@ -884,3 +871,96 @@ CM_RT_API int32_t CmQueue_RT::DestroyEventFast(CmEvent *&event)
     return CM_SUCCESS;
 }
 
+CM_RT_API int32_t CmQueue_RT::SetResidentGroupAndParallelThreadNum(uint32_t residentGroupNum, uint32_t parallelThreadNum)
+{
+    return CM_NOT_IMPLEMENTED;
+}
+
+
+CM_RT_API int32_t CmQueue_RT::EnqueueReadBuffer(CmBuffer* buffer,
+                                                size_t offset,
+                                                const unsigned char* sysMem,
+                                                uint64_t sysMemSize,
+                                                CmEvent* wait_event,
+                                                CmEvent*& event,
+                                                unsigned option)
+{
+    INSERT_PROFILER_RECORD();
+    CM_ENQUEUE_COPY_BUFFER_PARAM inParam;
+    CmSafeMemSet(&inParam, 0, sizeof(inParam));
+    inParam.cmQueueHandle = m_cmQueueHandle;
+    inParam.buffer = buffer;
+    inParam.sysMem = (void*)sysMem;
+    inParam.copySize = sysMemSize;
+    inParam.offset = offset;
+    inParam.copyDir = 0;
+    inParam.wait_event = wait_event;
+    inParam.option = option;
+    inParam.copyDir = CM_FASTCOPY_GPU2CPU;
+    inParam.cmEventHandle = event;
+
+    m_criticalSection.Acquire();
+
+    int32_t hr = m_cmDev->OSALExtensionExecute(CM_FN_CMQUEUE_ENQUEUECOPY_BUFFER,
+        &inParam,
+        sizeof(inParam));
+    if (FAILED(hr))
+    {
+        CmAssert(0);
+        m_criticalSection.Release();
+        return hr;
+    }
+    if (inParam.returnValue != CM_SUCCESS)
+    {
+        m_criticalSection.Release();
+        return inParam.returnValue;
+    }
+
+    event = static_cast<CmEvent*>(inParam.cmEventHandle);
+    m_criticalSection.Release();
+    return CM_SUCCESS;
+}
+
+CM_RT_API int32_t CmQueue_RT::EnqueueWriteBuffer(CmBuffer* buffer,
+                                                 size_t offset,
+                                                 const unsigned char* sysMem,
+                                                 uint64_t sysMemSize,
+                                                 CmEvent* wait_event,
+                                                 CmEvent*& event,
+                                                 unsigned option)
+{
+    INSERT_PROFILER_RECORD();
+    CM_ENQUEUE_COPY_BUFFER_PARAM inParam;
+    CmSafeMemSet(&inParam, 0, sizeof(inParam));
+    inParam.cmQueueHandle = m_cmQueueHandle;
+    inParam.buffer = buffer;
+    inParam.sysMem = (void*)sysMem;
+    inParam.copySize = sysMemSize;
+    inParam.offset = offset;
+    inParam.copyDir = 1;
+    inParam.wait_event = wait_event;
+    inParam.option = option;
+    inParam.copyDir = CM_FASTCOPY_CPU2GPU;
+    inParam.cmEventHandle = event;
+
+    m_criticalSection.Acquire();
+
+    int32_t hr = m_cmDev->OSALExtensionExecute(CM_FN_CMQUEUE_ENQUEUECOPY_BUFFER,
+        &inParam,
+        sizeof(inParam));
+    if (FAILED(hr))
+    {
+        CmAssert(0);
+        m_criticalSection.Release();
+        return hr;
+    }
+    if (inParam.returnValue != CM_SUCCESS)
+    {
+        m_criticalSection.Release();
+        return inParam.returnValue;
+    }
+
+    event = static_cast<CmEvent*>(inParam.cmEventHandle);
+    m_criticalSection.Release();
+    return CM_SUCCESS;
+}
