@@ -30,10 +30,6 @@
 
 #include "mhw_vebox.h"
 
-#define HDR_OETF_1DLUT_POINT_NUMBER                  256
-#define MHW_FORWARD_GAMMA_SEGMENT_CONTROL_POINT      1024
-#define MHW_VEBOX_STARTING_INDEX                     0
-
 template <class TVeboxCmds>
 class MhwVeboxInterfaceGeneric : public MhwVeboxInterface
 {
@@ -73,7 +69,7 @@ public:
         pVertexTable = (typename TVeboxCmds::VEBOX_VERTEX_TABLE_CMD *)(pVeboxHeap->pLockedDriverResourceMem +
                                                  pVeboxHeap->uiVertexTableOffset +
                                                  uiOffset);
-        memset(pVertexTable, 0, uSize);
+        MOS_ZeroMemory(pVertexTable, uSize);
         if (ColorSpace == MHW_CSpace_BT601 || ColorSpace == MHW_CSpace_xvYCC601)
         {
             MOS_SecureMemcpy(pVertexTable, uSize, g_VeboxVertexTableBT601, uSize);
@@ -102,6 +98,7 @@ public:
         typename TVeboxCmds::VEBOX_SURFACE_STATE_CMD cmd1, cmd2;
 
         MEDIA_FEATURE_TABLE    *pSkuTable = nullptr;
+        MHW_CHK_NULL(m_osInterface);
         pSkuTable = m_osInterface->pfnGetSkuTable(m_osInterface);
         MHW_CHK_NULL(pSkuTable);
         MHW_CHK_NULL(pCmdBuffer);
@@ -125,7 +122,7 @@ public:
             MHW_NORMALMESSAGE("Align Input Height as 8x due to 3DlutEnable");
         }
 
-        Mos_AddCommand(pCmdBuffer, &cmd1, cmd1.byteSize);
+        m_osInterface->pfnAddCommand(pCmdBuffer, &cmd1, cmd1.byteSize);
         MHW_NORMALMESSAGE("Vebox input Height: %d, Width: %d;", cmd1.DW2.Height, cmd1.DW2.Width);
 
         // Setup Surface State for Output surface
@@ -151,7 +148,7 @@ public:
                 MHW_NORMALMESSAGE("Align Output Height as 8x due to 3DlutEnable");
             }
 
-            Mos_AddCommand(pCmdBuffer, &cmd2, cmd2.byteSize);
+            m_osInterface->pfnAddCommand(pCmdBuffer, &cmd2, cmd2.byteSize);
             MHW_NORMALMESSAGE("Vebox output Height: %d, Width: %d;", cmd2.DW2.Height, cmd2.DW2.Width);
         }
 
@@ -287,6 +284,15 @@ protected:
             }
         }
 
+        if (pColorPipeParams->bEnableSTD)
+        {
+            if (nullptr == pColorPipeParams->StdParams.param || pColorPipeParams->StdParams.paraSizeInBytes > pVeboxStdSteState->byteSize)
+            {
+                MHW_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
+            }
+
+            MOS_SecureMemcpy(pVeboxStdSteState, pColorPipeParams->StdParams.paraSizeInBytes, pColorPipeParams->StdParams.param, pColorPipeParams->StdParams.paraSizeInBytes);
+        }
     finish:
         return eStatus;
     }
