@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2014-2018, Intel Corporation
+* Copyright (c) 2014-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -31,13 +31,11 @@
 #include "mhw_vdbox.h"
 #include "mhw_mi.h"
 #include "codec_def_encode_hevc.h"
+#include "mhw_vdbox_hcp_def.h"
 
 #define MHW_HCP_WORST_CASE_LCU_CU_TU_INFO        (26 * MHW_CACHELINE_SIZE) // 18+4+4
 #define MHW_HCP_WORST_CASE_LCU_CU_TU_INFO_REXT   (35 * MHW_CACHELINE_SIZE) // 27+4+4
 
-#define MHW_HCP_WORST_CASE_CU_TU_INFO            (4 * MHW_CACHELINE_SIZE) // 2+1+1
-#define MHW_HCP_WORST_CASE_CU_TU_INFO_REXT       (6 * MHW_CACHELINE_SIZE) // 4+1+1
-
 struct MHW_VDBOX_HEVC_PIC_STATE
 {
     // Decode
@@ -60,7 +58,7 @@ struct MHW_VDBOX_HEVC_PIC_STATE
     bool                                    bTransformSkipEnable = false;
 
     //FEI multiple passes PAK ---max frame size
-    uint8_t                                 currPass = 0;
+    uint16_t                                currPass = 0;
     uint8_t                                *deltaQp = nullptr;
     uint32_t                                maxFrameSize = 0;
     virtual ~MHW_VDBOX_HEVC_PIC_STATE(){}
@@ -349,6 +347,16 @@ public:
         hevcSliceP  = 1,
         hevcSliceI  = 2
     };
+    //!
+    //! \brief    Get max vdbox index
+    //!
+    //! \return   MHW_VDBOX_NODE_IND
+    //!           max vdbox index got
+    //!
+    inline MHW_VDBOX_NODE_IND GetMaxVdboxIndex()
+    {
+        return MEDIA_IS_SKU(m_skuTable, FtrVcs2) ? MHW_VDBOX_NODE_2 : MHW_VDBOX_NODE_1;
+    }
 
 protected:
     PMOS_INTERFACE              m_osInterface = nullptr; //!< Pointer to OS interface
@@ -382,6 +390,12 @@ protected:
 
     static const HevcSliceType  m_hevcBsdSliceType[3]; //!< HEVC Slice Types for Long Format
 
+    std::shared_ptr<void> m_hcpItfNew = nullptr;
+
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    bool bMMCReported = false;
+#endif
+
     //!
     //! \brief    Constructor
     //!
@@ -434,6 +448,14 @@ public:
     //!
     virtual ~MhwVdboxHcpInterface() {}
 
+    //!
+    //! \brief    Get new HCP interface, temporal solution before switching from
+    //!           old interface to new one
+    //!
+    //! \return   pointer to new HCP interface
+    //!
+    virtual std::shared_ptr<void> GetNewHcpInterface() { return nullptr; }
+
     //!
     //! \brief    Get OS interface
     //!
@@ -841,6 +863,22 @@ public:
         PMOS_COMMAND_BUFFER              cmdBuffer,
         PMHW_VDBOX_HEVC_PIC_STATE        params);
 
+    //!
+    //! \brief    Adds HCP Protect State command in command buffer
+    //! \details  Client facing function to add HCP picture State command for encode in command buffer
+    //!
+    //! \param    [in] cmdBuffer
+    //!           Command buffer to which HW command is added
+    //! \param    [in] hevcSliceState
+    //!           Params structure used to populate the HW command
+    //!
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    MOS_STATUS AddHcpProtectStateCmd(
+        PMOS_COMMAND_BUFFER              cmdBuffer,
+        PMHW_VDBOX_HEVC_SLICE_STATE      hevcSliceState);
+
     //!
     //! \brief    Programs base address of rowstore scratch buffers
     //! \details  Internal function to get base address of rowstore scratch buffers
@@ -1069,6 +1107,21 @@ public:
         PMOS_COMMAND_BUFFER              cmdBuffer,
         PMHW_VDBOX_HEVC_SLICE_STATE      hevcSliceState) = 0;
 
+    //!
+    //! \brief    Adds HCP Protect state command for decode in command buffer
+    //!
+    //! \param    [in] cmdBuffer
+    //!           Command buffer to which HW command is added
+    //! \param    [in] hevcSliceState
+    //!           Params structure used to populate the HW command
+    //!
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    virtual MOS_STATUS AddHcpDecodeProtectStateCmd(
+        PMOS_COMMAND_BUFFER              cmdBuffer,
+        PMHW_VDBOX_HEVC_SLICE_STATE      hevcSliceState) = 0;
+
     //!
     //! \brief    Adds HCP BSD object state command in command buffer
     //!
