@@ -487,9 +487,7 @@ protected:
     CmKernel *         m_cmKrnB       = nullptr;
     CmProgram *        m_cmProgramB   = nullptr;
     CmKernel *         m_cmKrnB64     = nullptr;
-    CmProgram *        m_cmProgramB64 = nullptr; 
-    static CmDevice *  m_mfeCmDev;
-    MbencBcurbeDataG12 m_curbeDataB = {};
+    CmProgram *        m_cmProgramB64 = nullptr;
 
     typedef SurfaceIndex MBencSurfaceIndex[m_maxMfeSurfaces][m_maxMultiFrames];
     MBencSurfaceIndex * m_surfIndexArray = nullptr;
@@ -516,7 +514,7 @@ protected:
     CmBuffer *              m_cuSplitSurf               = nullptr;                     //!< CU split data surface
     CmBuffer *              m_loadBalance               = nullptr;                     //!< Enc constant table for B LCU32
     CmBuffer *              m_dbgSurface                = nullptr;                     //!< Debug surface
-    
+
     CodechalKernelIntraDistMdfG12 *m_intraDistKernel = nullptr;
 
     //External surfaces
@@ -573,9 +571,6 @@ public:
     //!
     MOS_STATUS AllocateMeResources();
 
-
-   
-
 protected:
     //!
     //! \brief    Allocate resources used by MBEnc
@@ -587,7 +582,6 @@ protected:
 
     MOS_STATUS AllocateBrcResources()override;
 
-
     //!
     //! \brief    Free resources
     //!
@@ -597,7 +591,7 @@ protected:
     virtual MOS_STATUS FreeEncResources()override;
 
     virtual MOS_STATUS FreeBrcResources()override;
-    
+
     //!
     //! \brief    Free resources
     //!
@@ -605,7 +599,7 @@ protected:
     //!           MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS FreeMeResources();
-    
+
     //!
     //! \brief    Top level function for invoking MBenc kernel
     //! \details  I, B or LCU64_B MBEnc kernel, based on EncFunctionType
