@@ -1110,7 +1110,7 @@ MOS_STATUS CodechalEncodeMpeg2G12::SetAndPopulateVEHintParams(
 
 MOS_STATUS CodechalEncodeMpeg2G12::SubmitCommandBuffer(
     PMOS_COMMAND_BUFFER cmdBuffer,
-    int32_t             bNullRendering)
+    bool             bNullRendering)
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
@@ -1701,9 +1701,8 @@ MOS_STATUS CodechalEncodeMpeg2G12::SendMbEncSurfaces(
     surfaceCodecParams.dwVerticalLineStride = m_verticalLineStride;
     surfaceCodecParams.dwVerticalLineStrideOffset = m_verticalLineStrideOffset;
 
-#ifdef _MMC_SUPPORTED
     CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mmcState->SetSurfaceParams(&surfaceCodecParams));
-#endif
+
     CODECHAL_ENCODE_CHK_STATUS_RETURN(CodecHalSetRcsSurfaceState(
         m_hwInterface,
         cmdBuffer,
@@ -1723,9 +1722,8 @@ MOS_STATUS CodechalEncodeMpeg2G12::SendMbEncSurfaces(
     surfaceCodecParams.dwBindingTableOffset = m_mbEncBindingTable.m_mbEncCurrentPic;
     surfaceCodecParams.ucVDirection = vDirection;
 
-#ifdef _MMC_SUPPORTED
     CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mmcState->SetSurfaceParams(&surfaceCodecParams));
-#endif
+
     CODECHAL_ENCODE_CHK_STATUS_RETURN(CodecHalSetRcsSurfaceState(
         m_hwInterface,
         cmdBuffer,
@@ -1769,9 +1767,8 @@ MOS_STATUS CodechalEncodeMpeg2G12::SendMbEncSurfaces(
         surfaceCodecParams.dwCacheabilityControl =
             m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_SURFACE_REF_ENCODE].Value;
 
-#ifdef _MMC_SUPPORTED
         CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mmcState->SetSurfaceParams(&surfaceCodecParams));
-#endif
+
         CODECHAL_ENCODE_CHK_STATUS_RETURN(CodecHalSetRcsSurfaceState(
             m_hwInterface,
             cmdBuffer,
@@ -1779,9 +1776,9 @@ MOS_STATUS CodechalEncodeMpeg2G12::SendMbEncSurfaces(
             kernelState));
 
         surfaceCodecParams.dwBindingTableOffset = m_mbEncBindingTable.m_mbEncForwardPic + 1;
-#ifdef _MMC_SUPPORTED
+
         CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mmcState->SetSurfaceParams(&surfaceCodecParams));
-#endif
+
         CODECHAL_ENCODE_CHK_STATUS_RETURN(CodecHalSetRcsSurfaceState(
             m_hwInterface,
             cmdBuffer,
@@ -1809,9 +1806,8 @@ MOS_STATUS CodechalEncodeMpeg2G12::SendMbEncSurfaces(
         surfaceCodecParams.dwBindingTableOffset = m_mbEncBindingTable.m_mbEncBackwardPic;
         surfaceCodecParams.ucVDirection = vDirection;
 
-#ifdef _MMC_SUPPORTED
         CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mmcState->SetSurfaceParams(&surfaceCodecParams));
-#endif
+
         CODECHAL_ENCODE_CHK_STATUS_RETURN(CodecHalSetRcsSurfaceState(
             m_hwInterface,
             cmdBuffer,
@@ -1819,9 +1815,9 @@ MOS_STATUS CodechalEncodeMpeg2G12::SendMbEncSurfaces(
             kernelState));
 
         surfaceCodecParams.dwBindingTableOffset = m_mbEncBindingTable.m_mbEncBackwardPic + 1;
-#ifdef _MMC_SUPPORTED
+
         CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mmcState->SetSurfaceParams(&surfaceCodecParams));
-#endif
+
         CODECHAL_ENCODE_CHK_STATUS_RETURN(CodecHalSetRcsSurfaceState(
             m_hwInterface,
             cmdBuffer,
@@ -1842,9 +1838,8 @@ MOS_STATUS CodechalEncodeMpeg2G12::SendMbEncSurfaces(
         surfaceCodecParams.dwBindingTableOffset = m_mbEncBindingTable.m_mbEncInterlaceFrameCurrentPic;
         surfaceCodecParams.ucVDirection = vDirection;
 
-#ifdef _MMC_SUPPORTED
         CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mmcState->SetSurfaceParams(&surfaceCodecParams));
-#endif
+
         CODECHAL_ENCODE_CHK_STATUS_RETURN(CodecHalSetRcsSurfaceState(
             m_hwInterface,
             cmdBuffer,
@@ -1862,9 +1857,8 @@ MOS_STATUS CodechalEncodeMpeg2G12::SendMbEncSurfaces(
             surfaceCodecParams.dwBindingTableOffset = m_mbEncBindingTable.m_mbEncInterlaceFrameBackwardPic;
             surfaceCodecParams.ucVDirection = vDirection;
 
-#ifdef _MMC_SUPPORTED
             CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mmcState->SetSurfaceParams(&surfaceCodecParams));
-#endif
+
             CODECHAL_ENCODE_CHK_STATUS_RETURN(CodecHalSetRcsSurfaceState(
                 m_hwInterface,
                 cmdBuffer,
@@ -1873,9 +1867,8 @@ MOS_STATUS CodechalEncodeMpeg2G12::SendMbEncSurfaces(
 
             surfaceCodecParams.dwBindingTableOffset = m_mbEncBindingTable.m_mbEncInterlaceFrameBackwardPic + 1;
 
-#ifdef _MMC_SUPPORTED
             CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mmcState->SetSurfaceParams(&surfaceCodecParams));
-#endif
+
             CODECHAL_ENCODE_CHK_STATUS_RETURN(CodecHalSetRcsSurfaceState(
                 m_hwInterface,
                 cmdBuffer,
@@ -1966,10 +1959,10 @@ MOS_STATUS CodechalEncodeMpeg2G12::SendPrologWithFrameTracking(
 MOS_STATUS CodechalEncodeMpeg2G12::InitMmcState()
 {
     CODECHAL_ENCODE_FUNCTION_ENTER;
-#ifdef _MMC_SUPPORTED
+
     m_mmcState = MOS_New(CodechalMmcEncodeMpeg2G12, m_hwInterface, this);
     CODECHAL_ENCODE_CHK_NULL_RETURN(m_mmcState);
-#endif
+
     return MOS_STATUS_SUCCESS;
 }
 
