@@ -179,7 +179,7 @@ MOS_STATUS RenderHal_SendSurfaces_PatchList(
     if (pRenderHal->isBindlessHeapInUse)
     {
         bool bNeedNullPatch = MEDIA_IS_SKU(pOsInterface->pfnGetSkuTable(pOsInterface), FtrMediaPatchless);
-        MHW_RENDERHAL_CHK_STATUS_RETURN(pRenderHal->pfnSendBindlessSurfaceStates(pRenderHal, bNeedNullPatch));
+        MHW_RENDERHAL_CHK_STATUS_RETURN(pRenderHal->pfnSendBindlessSurfaceStates(pRenderHal, pCmdBuffer, bNeedNullPatch));
         return MOS_STATUS_SUCCESS;
     }
 
