@@ -92,10 +92,8 @@ namespace decode{
 
         m_avcPicParams      = m_avcBasicFeature->m_avcPicParams;
 
-#ifdef _MMC_SUPPORTED
         m_mmcState = m_avcPipeline->GetMmcState();
         DECODE_CHK_NULL(m_mmcState);
-#endif
 
         DECODE_CHK_STATUS(SetRowstoreCachingOffsets());
 
@@ -236,11 +234,10 @@ namespace decode{
         dstSurfaceParams.Mode      = CODECHAL_DECODE_MODE_AVCVLD;
         dstSurfaceParams.psSurface = &m_avcBasicFeature->m_destSurface;
 
-#ifdef _MMC_SUPPORTED
         DECODE_CHK_STATUS(m_mmcState->SetSurfaceMmcState(&(m_avcBasicFeature->m_destSurface)));
         DECODE_CHK_STATUS(m_mmcState->GetSurfaceMmcState(dstSurfaceParams.psSurface, &dstSurfaceParams.mmcState));
         DECODE_CHK_STATUS(m_mmcState->GetSurfaceMmcFormat(dstSurfaceParams.psSurface, &dstSurfaceParams.dwCompressionFormat));
-#endif
+
         return MOS_STATUS_SUCCESS;
     }
 
@@ -434,6 +431,8 @@ namespace decode{
         avcDirectmodeParams.avcRefList              = (void**)refFrames.m_refList;
         avcDirectmodeParams.bPicIdRemappingInUse    = m_avcBasicFeature->m_picIdRemappingInUse;
 
+        CODECHAL_DEBUG_TOOL(DECODE_CHK_STATUS(DumpResources(avcDirectmodeParams, curMvBuffer->size)));
+
         return MOS_STATUS_SUCCESS;
     }
 
@@ -578,6 +577,32 @@ namespace decode{
         return MOS_STATUS_SUCCESS;
     }
 
+    MOS_STATUS AvcDecodePicPktXe_M_Base::DumpResources(MHW_VDBOX_AVC_DIRECTMODE_PARAMS &avcDirectmodeParams, uint32_t mvBufferSize)
+    {
+        DECODE_FUNC_CALL();
+
+        CodechalDebugInterface *debugInterface = m_avcPipeline->GetDebugInterface();
+        for (auto n = 0; n < CODEC_AVC_MAX_NUM_REF_FRAME; n++)
+        {
+            if (m_avcBasicFeature->m_refFrames.m_avcPicIdx[n].bValid)
+            {
+                std::string mvBufDumpName = "_DEC_Ref_MV_" + std::to_string(n);
+                DECODE_CHK_STATUS(debugInterface->DumpBuffer(
+                    &avcDirectmodeParams.presAvcDmvBuffers[n+1],
+                    CodechalDbgAttr::attrMvData,
+                    mvBufDumpName.c_str(),
+                    mvBufferSize));
+            }
+        }
+
+        DECODE_CHK_STATUS(debugInterface->DumpBuffer(
+            &avcDirectmodeParams.presAvcDmvBuffers[0],
+            CodechalDbgAttr::attrMvData,
+            "DEC_Cur_MV_",
+            mvBufferSize));
+        return MOS_STATUS_SUCCESS;
+    }
+
 #endif
 
 }
