@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020-2022, Intel Corporation
+* Copyright (c) 2020-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -196,6 +196,7 @@ MOS_STATUS Vp9VdencPktXe_Lpm_Plus_Base::AddPictureVdencCommands(MOS_COMMAND_BUFF
     ENCODE_CHK_STATUS_RETURN(AddVdencSurfacesStateCmd(cmdBuffer));
     // Add vdenc pipeline buffer address command
     ENCODE_CHK_STATUS_RETURN(AddVdencPipeBufAddrCmd(cmdBuffer));
+
     // Add second level batch buffer command
     ENCODE_CHK_STATUS_RETURN(AddVdencSecondLevelBatchBufferCmd(cmdBuffer));
 
@@ -218,6 +219,7 @@ MOS_STATUS Vp9VdencPktXe_Lpm_Plus_Base::SetVdencPipeModeSelectParams(MHW_VDBOX_P
     ENCODE_CHK_STATUS_RETURN(Vp9VdencPkt::SetVdencPipeModeSelectParams(vdboxPipeModeSelectParams));
 
     auto pipeModeSelectParams = dynamic_cast<MHW_VDBOX_PIPE_MODE_SELECT_PARAMS *>(&vdboxPipeModeSelectParams);
+    ENCODE_CHK_NULL_RETURN(pipeModeSelectParams);
 
     auto dysRefFrameFlags         = m_basicFeature->m_ref.DysRefFrameFlags();
     auto dysVdencMultiPassEnabled = m_basicFeature->m_dysVdencMultiPassEnabled;
@@ -274,7 +276,7 @@ MOS_STATUS Vp9VdencPktXe_Lpm_Plus_Base::PatchPictureLevelCommands(MOS_COMMAND_BU
         if (m_pipeline->IsFirstPass())
         {
             // Reset multi-pipe sync semaphores
-            ENCODE_CHK_STATUS_RETURN(scalability->ResetSemaphore(syncOnePipeWaitOthers, 0, &cmdBuffer));
+            ENCODE_CHK_STATUS_RETURN(scalability->ResetSemaphore(syncOnePipeWaitOthers, m_pipeline->GetCurrentPipe(), &cmdBuffer));
         }
         if (m_basicFeature->m_hucEnabled)
         {
@@ -306,6 +308,14 @@ MOS_STATUS Vp9VdencPktXe_Lpm_Plus_Base::PatchPictureLevelCommands(MOS_COMMAND_BU
         {
             m_vdencPakObjCmdStreamOutEnabled = false;
         }
+
+        if (!m_basicFeature->m_hucEnabled)
+        {
+            // Construct picture state 2nd level batch buffer
+            RUN_FEATURE_INTERFACE_RETURN(Vp9EncodePak, Vp9FeatureIDs::vp9PakFeature, ConstructPicStateBatchBuffer, m_pipeline);
+            // Refresh internal bufferes
+            RUN_FEATURE_INTERFACE_RETURN(Vp9EncodeHpu, Vp9FeatureIDs::vp9HpuFeature, RefreshFrameInternalBuffers);
+        }
     }
 
     ENCODE_CHK_STATUS_RETURN(AddCondBBEndForLastPass(cmdBuffer));
@@ -478,8 +488,11 @@ MOS_STATUS Vp9VdencPktXe_Lpm_Plus_Base::PatchTileLevelCommands(MOS_COMMAND_BUFFE
 {
     ENCODE_FUNC_CALL();
 
-    // Update and construct pak insert batch buffer
-    RUN_FEATURE_INTERFACE_RETURN(Vp9EncodePak, Vp9FeatureIDs::vp9PakFeature, ConstructPakInsertObjBatchBuffer);
+    if (!m_basicFeature->m_hucEnabled)
+    {
+        // Construct pak insert batch buffer
+        RUN_FEATURE_INTERFACE_RETURN(Vp9EncodePak, Vp9FeatureIDs::vp9PakFeature, ConstructPakInsertObjBatchBuffer);
+    }
 
     if (m_pipeline->IsFirstPipe())
     {
