@@ -69,6 +69,9 @@ MOS_STATUS AvcBasicFeature::Init(void *setting)
     m_adaptiveRoundingInterEnable = (outValue.Get<int32_t>()) ? true : false;
 
     m_targetUsageOverride = (uint8_t)0;
+
+    m_brcAdaptiveRegionBoostSupported = true;
+
 #if (_DEBUG || _RELEASE_INTERNAL)
 
     outValue = 0;
@@ -91,13 +94,16 @@ MOS_STATUS AvcBasicFeature::Init(void *setting)
 
     m_perMBStreamOutEnable = (outValue.Get<int32_t>()) ? true : false;
 
+    outValue = 0;
+
     ReadUserSettingForDebug(
         m_userSettingPtr,
         outValue,
         "AVC VDEnc TCBRC ARB Disable",
         MediaUserSetting::Group::Sequence);
 
-    m_brcAdaptiveRegionBoostSupported = (outValue.Get<int32_t>()) ? false : true;
+    m_brcAdaptiveRegionBoostSupported = (outValue.Get<int32_t>()) ? false : m_brcAdaptiveRegionBoostSupported;
+
 #endif  // _DEBUG || _RELEASE_INTERNAL
 
     return MOS_STATUS_SUCCESS;
@@ -206,6 +212,28 @@ MOS_STATUS AvcBasicFeature::Update(void *params)
         m_perMBStreamOutEnable = true;
     }
 
+#if MHW_HWCMDPARSER_ENABLED
+    char frameType = '\0';
+    switch (m_picParam->CodingType)
+    {
+    case I_TYPE:
+        frameType = 'I';
+        break;
+    case P_TYPE:
+        frameType = 'P';
+        break;
+    case B_TYPE:
+        frameType = (m_picParam->RefPicFlag) ? 'B' : 'b';
+        break;
+    }
+
+    auto instance = mhw::HwcmdParser::GetInstance();
+    if (instance)
+    {
+        instance->Update(frameType, (void *)m_featureManager);
+    }
+#endif
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -253,8 +281,6 @@ MOS_STATUS AvcBasicFeature::SetSequenceStructs()
     seqParams->bit_depth_luma_minus8   = 0;
     seqParams->bit_depth_chroma_minus8 = 0;
 
-    seqParams->NumRefFrames = seqParams->NumRefFrames * 2;
-
     // setup parameters corresponding to H264 bit stream definition
     seqParams->pic_height_in_map_units_minus1       = seqParams->frame_mbs_only_flag ? CODECHAL_GET_HEIGHT_IN_MACROBLOCKS(seqParams->FrameHeight) - 1 : (CODECHAL_GET_HEIGHT_IN_MACROBLOCKS(seqParams->FrameHeight) + 1) / 2 - 1;
     seqParams->pic_width_in_mbs_minus1              = CODECHAL_GET_WIDTH_IN_MACROBLOCKS(seqParams->FrameWidth) - 1;
@@ -424,9 +450,28 @@ MOS_STATUS AvcBasicFeature::SetPictureStructs()
         m_lastPicInSeq = m_lastPicInStream = 0;
     }
 
-    m_frameFieldHeight     = m_frameHeight;
-    m_frameFieldHeightInMb = m_picHeightInMb;
-    m_firstField           = 1;
+    // see implementation in CodechalEncodeAvcBase::SetPictureStructs()
+    if (picParams->FieldCodingFlag == 1)
+    {
+        m_frameFieldHeight     = ((m_frameHeight + 1) >> 1);
+        m_frameFieldHeightInMb = ((m_picHeightInMb + 1) >> 1);
+        
+        if (CodecHal_PictureIsFrame(prevPic) || prevIdx != currIdx ||
+            ((prevPic.PicFlags != currPic.PicFlags) && !(slcParams->pic_order_cnt_lsb & 1)))
+        {
+            m_firstField = 1;
+        }
+        else
+        {
+            m_firstField = 0;
+        }
+    }
+    else
+    {
+        m_frameFieldHeight     = m_frameHeight;
+        m_frameFieldHeightInMb = m_picHeightInMb;
+        m_firstField = 1;
+    }
 
     seqParams->mb_adaptive_frame_field_flag = 0;
     m_mbaffEnabled                          = 0;
@@ -434,14 +479,14 @@ MOS_STATUS AvcBasicFeature::SetPictureStructs()
     if ((m_lookaheadDepth > 0) && (m_prevTargetFrameSize > 0))
     {
         int64_t targetBufferFulness = (int64_t)m_targetBufferFulness;
-        targetBufferFulness += (int64_t)(m_prevTargetFrameSize << 3) - (int64_t)m_averageFrameSize;
+        targetBufferFulness += (((int64_t)m_prevTargetFrameSize) << 3) - (int64_t)m_averageFrameSize;
         m_targetBufferFulness = (uint32_t)MOS_CLAMP_MIN_MAX(targetBufferFulness, 0, 0xFFFFFFFF);
     }
     m_prevTargetFrameSize = picParams->TargetFrameSize;
 
-    if (picParams->FieldCodingFlag || picParams->FieldFrameCodingFlag)
+    if (picParams->FieldFrameCodingFlag)
     {
-        ENCODE_ASSERTMESSAGE("VDEnc does not support interlaced picture\n");
+        ENCODE_ASSERTMESSAGE("VDEnc does not support Field-Frame coding\n");
         eStatus = MOS_STATUS_INVALID_PARAMETER;
         return eStatus;
     }
@@ -517,12 +562,6 @@ MOS_STATUS AvcBasicFeature::SetSliceStructs()
         }
         else  // SLICE_STRUCT_ARBITRARYMBSLICE
         {
-            uint8_t ppsIdx          = m_sliceParams->pic_parameter_set_id;
-            uint8_t refPicListIdx   = m_sliceParams[ppsIdx].RefPicList[0][0].FrameIdx;
-            uint8_t refFrameListIdx = m_picParam[ppsIdx].RefFrameList[refPicListIdx].FrameIdx;
-
-            bool dirtyRoiEnabled = (m_pictureCodingType == P_TYPE && m_picParams[ppsIdx]->NumDirtyROI > 0 && m_prevReconFrameIdx == refFrameListIdx);
-
             if ((slcParams->NumMbsForSlice % m_picWidthInMb) ||                                          // If slice is partial MB row,
                 ((sliceCount < m_numSlices - 1) && (numMbsInPrevSlice != slcParams->NumMbsForSlice)) ||  // OR not the last slice and num mbs is not same as prev slice
                 ((sliceCount == m_numSlices - 1) && ((numMbsInPrevSlice < slcParams->NumMbsForSlice))))  // OR it is the last slice and num mbs is not less than prev slice
@@ -540,10 +579,6 @@ MOS_STATUS AvcBasicFeature::SetSliceStructs()
         {
             slcParams->slice_qp_delta = CODECHAL_ENCODE_AVC_MAX_SLICE_QP - (picParams->pic_init_qp_minus26 + 26);
         }
-        else
-        {
-            slcParams->slice_qp_delta = slcParams->slice_qp_delta;
-        }
         slcParams->redundant_pic_cnt                  = 0;
         slcParams->sp_for_switch_flag                 = 0;
         slcParams->slice_qs_delta                     = 0;
@@ -568,13 +603,22 @@ void AvcBasicFeature::CheckResolutionChange()
 
     uint32_t frameWidth = m_seqParam->FrameWidth;
     uint32_t frameHeight = m_seqParam->FrameHeight;
+    uint16_t frame_crop_bottom_offset = m_seqParam->frame_crop_bottom_offset;
+    uint16_t frame_mbs_only_flag      = m_seqParam->frame_mbs_only_flag;
+    uint16_t frame_cropping_flag      = m_seqParam->frame_cropping_flag;
 
     // Only for first frame
     if (m_frameNum == 0)
     {
         m_oriFrameHeight = frameHeight;
         m_oriFrameWidth = frameWidth;
+        m_frame_crop_bottom_offset = frame_crop_bottom_offset;
+        m_frame_mbs_only_flag        = frame_mbs_only_flag;
+        m_frame_cropping_flag      = frame_cropping_flag;
         m_resolutionChanged = true;
+        // Initialize previous resolution to 0 for first frame
+        m_prevFrameHeight = 0;
+        m_prevFrameWidth  = 0;
     }
     else
     {
@@ -583,8 +627,14 @@ void AvcBasicFeature::CheckResolutionChange()
             (m_oriFrameWidth && (m_oriFrameWidth != frameWidth)))
         {
             m_resolutionChanged = true;
+            // Save current as previous before update
+            m_prevFrameHeight = m_oriFrameHeight;
+            m_prevFrameWidth = m_oriFrameWidth;
             m_oriFrameHeight = frameHeight;
             m_oriFrameWidth = frameWidth;
+            m_frame_crop_bottom_offset = frame_crop_bottom_offset;
+            m_frame_mbs_only_flag      = frame_mbs_only_flag;
+            m_frame_cropping_flag      = frame_cropping_flag;
         }
         else
         {
@@ -617,13 +667,67 @@ MOS_STATUS AvcBasicFeature::PackPictureHeader()
     return MOS_STATUS_SUCCESS;
 }
 
+bool AvcBasicFeature::InputSurfaceNeedsExtraCopy(const MOS_SURFACE &input)
+{
+#if _DEBUG || _RELEASE_INTERNAL
+    static int8_t supported = -1;
+
+    if (supported == -1)
+    {
+        MediaUserSetting::Value outValue{};
+
+        ReadUserSettingForDebug(
+            m_userSettingPtr,
+            outValue,
+            "DisableInputSurfaceCopy",
+            MediaUserSetting::Group::Sequence);
+
+        supported = !outValue.Get<bool>();
+    }
+
+    if (!supported)
+    {
+        return false;
+    }
+#endif
+
+    if (m_osInterface->osCpInterface && m_osInterface->osCpInterface->IsCpEnabled())
+    {
+        return false;
+    }
+
+    uint32_t alignedSize = 0;
+    switch (input.Format)
+    {
+    case Format_NV12:
+        alignedSize = MOS_MAX((uint32_t)m_seqParam->FrameWidth, (uint32_t)input.dwPitch) * m_seqParam->FrameHeight * 3 / 2;
+        break;
+    case Format_A8R8G8B8:
+        alignedSize = MOS_MAX((uint32_t)m_seqParam->FrameWidth * 4, (uint32_t)input.dwPitch) * m_seqParam->FrameHeight;
+        break;
+    default:
+        alignedSize = 0;
+        break;
+    }
+
+    return input.dwSize < alignedSize;
+}
+
 MOS_STATUS AvcBasicFeature::UpdateTrackedBufferParameters()
 {
+    ENCODE_FUNC_CALL();
+    ENCODE_CHK_NULL_RETURN(m_trackedBuf);
+
+    ENCODE_CHK_STATUS_RETURN(m_trackedBuf->OnSizeChange());
+
     uint32_t fieldNumMBs = (uint32_t)m_picWidthInMb * ((m_picHeightInMb + 1) >> 1);
 
     m_mbCodeSize = MOS_ALIGN_CEIL(fieldNumMBs * 16 * 4, CODECHAL_PAGE_SIZE) + fieldNumMBs * 16 * 4;
     m_mvDataSize = 0;
-    m_colocatedMVBufferSize = (((uint32_t)m_picHeightInMb * m_picWidthInMb + 1) >> 1) * CODECHAL_CACHELINE_SIZE; // Cacheline per 2 MBs
+
+    uint32_t widthInMbRoundUp  = (m_frameWidth + 31) >> 4;
+    uint32_t heightInMbRoundUp = (m_frameHeight + 15) >> 4;
+    m_colocatedMVBufferSize    = widthInMbRoundUp * heightInMbRoundUp * CODECHAL_CACHELINE_SIZE / 2; // Cacheline per 2 MBs
 
     MOS_ALLOC_GFXRES_PARAMS allocParams;
     MOS_ZeroMemory(&allocParams, sizeof(MOS_ALLOC_GFXRES_PARAMS));
@@ -659,6 +763,19 @@ MOS_STATUS AvcBasicFeature::UpdateTrackedBufferParameters()
         m_allocator->UnLock(m_colocatedMVBufferForIFrames);
     }
 
+    // Input surface copy is needed if height is not MB aligned
+    if (InputSurfaceNeedsExtraCopy(m_rawSurface))
+    {
+        MOS_ALLOC_GFXRES_PARAMS allocParamsForAlignedRawSurface{};
+        allocParamsForAlignedRawSurface.Type     = MOS_GFXRES_2D;
+        allocParamsForAlignedRawSurface.Format   = m_rawSurface.Format;
+        allocParamsForAlignedRawSurface.TileType = MOS_TILE_Y;
+        allocParamsForAlignedRawSurface.dwWidth  = m_picWidthInMb * CODECHAL_MACROBLOCK_WIDTH;
+        allocParamsForAlignedRawSurface.dwHeight = m_picHeightInMb * CODECHAL_MACROBLOCK_HEIGHT;
+        allocParamsForAlignedRawSurface.pBufName = "Aligned Raw Surface";
+        ENCODE_CHK_STATUS_RETURN(m_trackedBuf->RegisterParam(BufferType::AlignedRawSurface, allocParamsForAlignedRawSurface));
+    }
+
     ENCODE_CHK_STATUS_RETURN(EncodeBasicFeature::UpdateTrackedBufferParameters());
 
     return MOS_STATUS_SUCCESS;
@@ -707,15 +824,23 @@ MOS_STATUS AvcBasicFeature::UpdateSeiParameters(EncoderParams* params)
     return eStatus;
 }
 
+uint8_t AvcBasicFeature::GetMinAvcQp()
+{
+    ENCODE_FUNC_CALL();
+    return CODEC_AVC_MIN_QP10;  // Default minimum QP for base class (value: 10)
+}
+
 void AvcBasicFeature::UpdateMinMaxQp()
 {
     ENCODE_FUNC_CALL();
 
+    uint8_t minAvcQp = GetMinAvcQp();  // Get platform-specific minimum QP
+
     m_minMaxQpControlEnabled = true;
     if (m_picParam->CodingType == I_TYPE)
     {
-        m_iMaxQp = MOS_MIN(MOS_MAX(m_picParam->ucMaximumQP, 10), 51);        // Clamp maxQP to [10, 51]
-        m_iMinQp = MOS_MIN(MOS_MAX(m_picParam->ucMinimumQP, 10), m_iMaxQp);  // Clamp minQP to [10, maxQP] to make sure minQP <= maxQP
+        m_iMaxQp = MOS_MIN(MOS_MAX(m_picParam->ucMaximumQP, minAvcQp), CODEC_AVC_MAX_QP);        // Clamp maxQP to [minAvcQp, CODEC_AVC_MAX_QP]
+        m_iMinQp = MOS_MIN(MOS_MAX(m_picParam->ucMinimumQP, minAvcQp), m_iMaxQp);  // Clamp minQP to [minAvcQp, maxQP] to make sure minQP <= maxQP
         if (!m_pFrameMinMaxQpControl)
         {
             m_pMinQp = m_iMinQp;
@@ -730,8 +855,8 @@ void AvcBasicFeature::UpdateMinMaxQp()
     else if (m_picParam->CodingType == P_TYPE)
     {
         m_pFrameMinMaxQpControl = true;
-        m_pMaxQp                = MOS_MIN(MOS_MAX(m_picParam->ucMaximumQP, 10), 51);        // Clamp maxQP to [10, 51]
-        m_pMinQp                = MOS_MIN(MOS_MAX(m_picParam->ucMinimumQP, 10), m_pMaxQp);  // Clamp minQP to [10, maxQP] to make sure minQP <= maxQP
+        m_pMaxQp                = MOS_MIN(MOS_MAX(m_picParam->ucMaximumQP, minAvcQp), CODEC_AVC_MAX_QP);        // Clamp maxQP to [minAvcQp, CODEC_AVC_MAX_QP]
+        m_pMinQp                = MOS_MIN(MOS_MAX(m_picParam->ucMinimumQP, minAvcQp), m_pMaxQp);  // Clamp minQP to [minAvcQp, maxQP] to make sure minQP <= maxQP
         if (!m_bFrameMinMaxQpControl)
         {
             m_bMinQp = m_pMinQp;
@@ -741,8 +866,8 @@ void AvcBasicFeature::UpdateMinMaxQp()
     else  // B_TYPE
     {
         m_bFrameMinMaxQpControl = true;
-        m_bMaxQp                = MOS_MIN(MOS_MAX(m_picParam->ucMaximumQP, 10), 51);        // Clamp maxQP to [10, 51]
-        m_bMinQp                = MOS_MIN(MOS_MAX(m_picParam->ucMinimumQP, 10), m_bMaxQp);  // Clamp minQP to [10, maxQP] to make sure minQP <= maxQP
+        m_bMaxQp                = MOS_MIN(MOS_MAX(m_picParam->ucMaximumQP, minAvcQp), CODEC_AVC_MAX_QP);        // Clamp maxQP to [minAvcQp, CODEC_AVC_MAX_QP]
+        m_bMinQp                = MOS_MIN(MOS_MAX(m_picParam->ucMinimumQP, minAvcQp), m_bMaxQp);  // Clamp minQP to [minAvcQp, maxQP] to make sure minQP <= maxQP
     }
     // Zero out the QP values, so we don't update the AVCState settings until new values are sent in MiscParamsRC
     m_picParam->ucMinimumQP = 0;
@@ -881,7 +1006,19 @@ MOS_STATUS AvcBasicFeature::GetTrackedBuffers()
     ENCODE_CHK_NULL_RETURN(m_allocator);
 
     auto currRefList = m_ref->GetCurrRefList();
-    ENCODE_CHK_STATUS_RETURN(m_trackedBuf->Acquire(currRefList, false));
+
+    // when encoding fields only Acquire the first field, or else encoder will hang
+    if (CodecHal_PictureIsTopField(m_currOriginalPic) || CodecHal_PictureIsBottomField(m_currOriginalPic))
+    {
+        if (m_firstField)
+        {
+            ENCODE_CHK_STATUS_RETURN(m_trackedBuf->Acquire(currRefList, false));
+        }
+    }
+    else
+    {
+        ENCODE_CHK_STATUS_RETURN(m_trackedBuf->Acquire(currRefList, false));
+    }
 
     m_resMbCodeBuffer = m_trackedBuf->GetBuffer(BufferType::mbCodedBuffer, m_trackedBuf->GetCurrIndex());
     ENCODE_CHK_NULL_RETURN(m_resMbCodeBuffer);
@@ -890,6 +1027,31 @@ MOS_STATUS AvcBasicFeature::GetTrackedBuffers()
     ENCODE_CHK_NULL_RETURN(m_4xDSSurface);
     ENCODE_CHK_STATUS_RETURN(m_allocator->GetSurfaceInfo(m_4xDSSurface));
 
+    // Input surface copy is needed if height is not MB aligned
+    if (InputSurfaceNeedsExtraCopy(m_rawSurface))
+    {
+        auto alignedRawSurf = m_trackedBuf->GetSurface(BufferType::AlignedRawSurface, m_trackedBuf->GetCurrIndex());
+        ENCODE_CHK_NULL_RETURN(alignedRawSurf);
+        m_allocator->GetSurfaceInfo(alignedRawSurf);
+        alignedRawSurf->OsResource.pGmmResInfo->GetSetCpSurfTag(true, m_rawSurface.OsResource.pGmmResInfo->GetSetCpSurfTag(false, 0));
+        ENCODE_CHK_STATUS_RETURN(m_allocator->UpdateResourceUsageType(&alignedRawSurf->OsResource, MOS_HW_RESOURCE_USAGE_ENCODE_INPUT_RAW));
+
+        if (m_mediaCopyWrapper)
+        {
+            ENCODE_CHK_STATUS_RETURN(m_mediaCopyWrapper->MediaCopy(
+                &m_rawSurface.OsResource,
+                &alignedRawSurf->OsResource,
+                MCPY_METHOD_DEFAULT));
+
+            m_rawSurface      = *alignedRawSurf;
+            m_rawSurfaceToEnc = m_rawSurfaceToPak = &m_rawSurface;
+        }
+        else
+        {
+            ENCODE_ASSERTMESSAGE("Input surface height %d is not 16-aligned, needs extra copy but MediaCopy is not avaliable.", m_rawSurface.dwHeight);
+        }
+    }
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -1016,6 +1178,12 @@ MHW_SETPAR_DECL_SRC(VDENC_PIPE_MODE_SELECT, AvcBasicFeature)
     params.VdencPipeModeSelectPar1 = par1table[m_seqParam->TargetUsage - 1];
     params.VdencPipeModeSelectPar0 = 1;
 
+    if (m_seqParam->EnableStreamingBufferLLC || m_seqParam->EnableStreamingBufferDDR)
+    {
+        params.streamingBufferConfig = 1; // STREAMING_BUFFER_64
+        params.captureMode           = 2; // CAPTURE_MODE_PARALLEFROMCAMERAPIPE
+    }
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -1091,7 +1259,6 @@ MHW_SETPAR_DECL_SRC(VDENC_PIPE_BUF_ADDR_STATE, AvcBasicFeature)
     params.streamOutBuffer = m_recycleBuf->GetBuffer(VdencStatsBuffer, 0);
     params.surfaceDsStage1 = m_4xDSSurface;
 
-#ifdef _MMC_SUPPORTED
         ENCODE_CHK_NULL_RETURN(m_mmcState);
         if (m_mmcState->IsMmcEnabled())
         {
@@ -1123,7 +1290,6 @@ MHW_SETPAR_DECL_SRC(VDENC_PIPE_BUF_ADDR_STATE, AvcBasicFeature)
             params.mmcStatePreDeblock = MOS_MEMCOMP_DISABLED;
             params.mmcStateRaw = MOS_MEMCOMP_DISABLED;
         }
-#endif
 
     if (m_ref->GetRefList()[m_currReconstructedPic.FrameIdx]->bUsedAsRef)
     {
@@ -1183,6 +1349,19 @@ MHW_SETPAR_DECL_SRC(VDENC_AVC_IMG_STATE, AvcBasicFeature)
     params.pictureHeightMinusOne = m_picHeightInMb - 1;
     params.pictureWidth          = m_picWidthInMb;
 
+    if (m_picParam->FieldCodingFlag) {
+        params.plAdaptFrameField = 1;
+        params.currFrmFldPic = 1;
+        if (m_picParam->CurrOriginalPic.PicFlags == PICTURE_TOP_FIELD)
+            params.curPicType = 2;
+        else
+            params.curPicType = 3;
+    } else {
+        params.plAdaptFrameField = 0;
+        params.currFrmFldPic = 0;
+        params.curPicType = 0;
+    }
+
     ENCODE_CHK_STATUS_RETURN(m_ref->MHW_SETPAR_F(VDENC_AVC_IMG_STATE)(params));
 
     if (m_ref->GetRefList()[m_currReconstructedPic.FrameIdx]->bUsedAsRef && m_pictureCodingType != I_TYPE)
@@ -1435,12 +1614,11 @@ MHW_SETPAR_DECL_SRC(MFX_SURFACE_STATE, AvcBasicFeature)
             MOS_ALIGN_CEIL((psSurface->VPlaneOffset.iSurfaceOffset - psSurface->dwOffset)/psSurface->dwPitch + psSurface->RenderOffset.YUV.V.YOffset, uvPlaneAlignment);
     }
 
-#ifdef _MMC_SUPPORTED
     if (m_mmcState && m_mmcState->IsMmcEnabled())
     {
         ENCODE_CHK_STATUS_RETURN(m_mmcState->GetSurfaceMmcFormat(psSurface, &params.compressionFormat));
     }
-#endif
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -1455,7 +1633,6 @@ MHW_SETPAR_DECL_SRC(MFX_PIPE_BUF_ADDR_STATE, AvcBasicFeature)
 
     ENCODE_CHK_STATUS_RETURN(m_ref->MHW_SETPAR_F(MFX_PIPE_BUF_ADDR_STATE)(params));
 
-#ifdef _MMC_SUPPORTED
     MOS_MEMCOMP_STATE reconSurfMmcState = MOS_MEMCOMP_DISABLED;
     if (m_mmcState->IsMmcEnabled())
     {
@@ -1481,7 +1658,7 @@ MHW_SETPAR_DECL_SRC(MFX_PIPE_BUF_ADDR_STATE, AvcBasicFeature)
 
     CODECHAL_DEBUG_TOOL(
         params.psPreDeblockSurface->MmcState = reconSurfMmcState;)
-#endif
+
     return MOS_STATUS_SUCCESS;
 }
 
