@@ -48,6 +48,32 @@ public:
         MHW_FUNCTION_ENTER;
     }
 
+    //!
+    //! \brief    Get Fast Tiling Mode
+    //! \details  BLT function to get the tiling mode for fast copy
+    //! \param    [in] TileType
+    //!           Tile type from BLT_TILE_TYPE enum
+    //! \return   uint32_t
+    //!           return the tiling mode value
+    //!
+    uint32_t GetFastTilingMode(BLT_TILE_TYPE TileType) override
+    {
+        MHW_FUNCTION_ENTER;
+        switch (TileType)
+        {
+        case BLT_NOT_TILED:
+            return cmd_t::XY_FAST_COPY_BLT_CMD::DESTINATION_TILING_METHOD_LINEAR_TILINGDISABLED;
+        case BLT_TILED_Y:
+        case BLT_TILED_4:
+            return cmd_t::XY_FAST_COPY_BLT_CMD::DESTINATION_TILING_METHOD_TILE_Y;
+        case BLT_TILED_64:
+            return cmd_t::XY_FAST_COPY_BLT_CMD::DESTINATION_TILING_METHOD_64KBTILING;
+        default:
+            MHW_ASSERTMESSAGE("BLT: Can't support GMM TileType %d.", TileType);
+        }
+        return cmd_t::XY_FAST_COPY_BLT_CMD::DESTINATION_TILING_METHOD_LINEAR_TILINGDISABLED;
+    }
+
     //!
     //! \brief    Add Block copy Command
     //! \details  BLT function to add block copy command
@@ -215,6 +241,10 @@ public:
             cmd.DW0.ColorDepth, cmd.DW8.SourcePitch, cmd.DW8.SourceMocs, cmd.DW8.SourceTiling, srcMmcModel,
             cmd.DW1.DestinationPitch, cmd.DW1.DestinationMocsValue, cmd.DW1.DestinationTiling, dstMmcModel);
 
+        MT_LOG7(MT_MEDIA_COPY, MT_NORMAL, MT_GENERIC_VALUE, cmd.DW0.ColorDepth, MT_GENERIC_VALUE, cmd.DW1.Value, MT_GENERIC_VALUE, cmd.DW2.Value, MT_GENERIC_VALUE, cmd.DW3.Value,
+                MT_GENERIC_VALUE, cmd.DW6.Value, MT_GENERIC_VALUE, cmd.DW7.Value, MT_GENERIC_VALUE, cmd.DW8.Value);
+        MT_LOG7(MT_MEDIA_COPY, MT_NORMAL, MT_GENERIC_VALUE, cmd.DW11.Value, MT_GENERIC_VALUE, cmd.DW16.Value, MT_GENERIC_VALUE, cmd.DW17.Value,
+                    MT_GENERIC_VALUE, cmd.DW18.Value, MT_GENERIC_VALUE, cmd.DW19.Value, MT_GENERIC_VALUE, cmd.DW20.Value, MT_GENERIC_VALUE, cmd.DW21.Value);
         return MOS_STATUS_SUCCESS;
     }
 
