@@ -58,6 +58,8 @@ public:
 
     virtual MOS_STATUS VeboxAdjustBoundary(PMHW_VEBOX_SURFACE_PARAMS pCurrSurf, uint32_t* pdwSurfaceWidth, uint32_t* pdwSurfaceHeight, bool bDIEnable) = 0;
 
+    virtual void SetForceInputHeight8AlignedFlag(bool forceInputHeight8Aligned) = 0;
+
     virtual MOS_STATUS SetVeboxIndex(uint32_t dwVeboxIndex, uint32_t dwVeboxCount, uint32_t dwUsingSFC) = 0;
 
     virtual MOS_STATUS DestroyHeap() = 0;
@@ -110,10 +112,14 @@ public:
 
     virtual bool IsVeboxScalabilitywith4K() = 0;
 
-    virtual MOS_STATUS Add1DLutState(void *&surface, PMHW_1DLUT_PARAMS p1DLutParams) = 0;
+    virtual MOS_STATUS Add1DLutState(void *surface, PMHW_1DLUT_PARAMS p1DLutParams) = 0;
 
     virtual MOS_STATUS AddFP16State(PMHW_FP16_PARAMS pFP16Params) = 0;
+#if (_DEBUG || _RELEASE_INTERNAL)
+    virtual bool IsVeboxIdReportEnabled() = 0;
 
+    virtual MOS_STATUS ReportVeboxId() = 0;
+#endif
     _VEBOX_CMD_DEF(_MHW_CMD_ALL_DEF_FOR_ITF);
 
 MEDIA_CLASS_DEFINE_END(mhw__vebox__Itf)
